@@ -12,7 +12,7 @@ from kfsd.apps.models.constants import MAX_LENGTH, MIN_LENGTH, MSMQ_NAME_REGEX_C
 
 
 class MsgQueueSerializer(serializers.Serializer):
-    exchange_name = serializers.CharField(
+    exchange = serializers.CharField(
         validators=[
             MinLengthValidator(MIN_LENGTH),
             MaxLengthValidator(MAX_LENGTH),
@@ -25,20 +25,8 @@ class MsgQueueSerializer(serializers.Serializer):
             ),
         ]
     )
-    queue_name = serializers.CharField(
-        validators=[
-            MinLengthValidator(MIN_LENGTH),
-            MaxLengthValidator(MAX_LENGTH),
-            RegexValidator(
-                MSMQ_NAME_REGEX_CONDITION,
-                message=_(
-                    "queue name has to match {}".format(MSMQ_NAME_REGEX_CONDITION)
-                ),
-                code="queue_invalid_name",
-            ),
-        ]
-    )
     routing_key = serializers.CharField(required=False, allow_blank=True)
+    properties = serializers.JSONField(default=dict)
 
 
 class MsgSerializer(serializers.Serializer):
@@ -56,7 +44,6 @@ class MsgSerializer(serializers.Serializer):
         ],
         required=True,
     )
-    type = serializers.ChoiceField(choices=["REPEAT", "ONETIME"], required=False)
     data = serializers.JSONField(default=dict)
 
 
