@@ -1,5 +1,6 @@
 from rest_framework import status
 from django.urls import reverse
+from unittest.mock import patch
 
 from kfsd.apps.endpoints.tests.endpoints_test_handler import EndpointsTestHandler
 
@@ -13,13 +14,17 @@ class ConfigurationTestCases(EndpointsTestHandler):
         self.assertEqual(response.status_code, expStatus)
         print(response)
 
-    def test_common_config_dev(self):
+    @patch("kfsd.apps.core.auth.api.token.TokenAuth.getTokenUserInfo")
+    @patch("kfsd.apps.core.common.kubefacets_config.KubefacetsConfig.getConfig")
+    def test_common_config_dev(self, genCommonConfigMocked, tokenUserInfoMocked):
         postData = self.readJSONData('kfsd/apps/endpoints/tests/v1/data/requests/common/config/test_common_config_dev.json')
         obsResponse = self.post(reverse("common-config"), postData, status.HTTP_200_OK)
         expResponse = self.readJSONData('kfsd/apps/endpoints/tests/v1/data/responses/common/config/test_common_config_dev.json')
         self.assertEqual(obsResponse, expResponse)
 
-    def test_common_config_prod(self):
+    @patch("kfsd.apps.core.auth.api.token.TokenAuth.getTokenUserInfo")
+    @patch("kfsd.apps.core.common.kubefacets_config.KubefacetsConfig.getConfig")
+    def test_common_config_prod(self, genCommonConfigMocked, tokenUserInfoMocked):
         postData = self.readJSONData('kfsd/apps/endpoints/tests/v1/data/requests/common/config/test_common_config_prod.json')
         obsResponse = self.post(reverse("common-config"), postData, status.HTTP_200_OK)
         expResponse = self.readJSONData('kfsd/apps/endpoints/tests/v1/data/responses/common/config/test_common_config_prod.json')
