@@ -26,20 +26,20 @@ class OutpostV1Doc:
                     {
                         "identifier": "9fe1f2f2221c6b6a0f28dde862d55299",
                         "msg_queue_info": {
-                            "exchange_name": "remind.exchange",
-                            "queue_name": "remind.queue",
-                            "routing_key": "remind.queue.route.key",
+                            "exchange": "kubefacets.exchange",
+                            "routing_key": "producer.actions.remind.create_reminder",
+                            "properties": {"delivery_mode": 2},
                         },
                         "msg": {
                             "action": "CREATE_REMINDER",
-                            "type": "ONETIME",
                             "data": {
                                 "identifier": "ORG=Kubefacets,APP=Certs,PRJ=Auth,COLL=Login,CSR=kubefacets Root CA",
+                                "type": "ONETIME",
                                 "remind_by_in_mins": 10,
                                 "to_msg_queue": {
-                                    "exchange_name": "certs.exchange",
-                                    "queue_name": "certs.queue",
-                                    "routing_key": "certs.queue.route.key",
+                                    "exchange": "kubefacets.exchange",
+                                    "routing_key": "producer.actions.certs.reorder_cert",
+                                    "properties": {"delivery_mode": 2},
                                 },
                                 "msg": {
                                     "action": "REORDER_CERT",
@@ -62,9 +62,9 @@ class OutpostV1Doc:
                         },
                         "msg": {
                             "action": "CREATE_REMINDER",
-                            "type": "ONETIME",
                             "data": {
                                 "identifier": "ORG=Kubefacets,APP=Certs,PRJ=Auth,COLL=Login,CSR=kubefacets Root CA",
+                                "type": "ONETIME",
                                 "remind_by_in_mins": 10,
                                 "to_msg_queue": {
                                     "exchange_name": "certs.exchange",
@@ -122,9 +122,9 @@ class OutpostV1Doc:
                     },
                     "msg": {
                         "action": "CREATE_REMINDER",
-                        "type": "ONETIME",
                         "data": {
                             "identifier": "ORG=Kubefacets,APP=Certs,PRJ=Auth,COLL=Login,CSR=kubefacets Root CA",
+                            "type": "ONETIME",
                             "remind_by_in_mins": 10,
                             "to_msg_queue": {
                                 "exchange_name": "certs.exchange",
@@ -161,9 +161,9 @@ class OutpostV1Doc:
                     },
                     "msg": {
                         "action": "CREATE_REMINDER",
-                        "type": "ONETIME",
                         "data": {
                             "identifier": "ORG=Kubefacets,APP=Certs,PRJ=Auth,COLL=Login,CSR=kubefacets Root CA",
+                            "type": "ONETIME",
                             "remind_by_in_mins": 10,
                             "to_msg_queue": {
                                 "exchange_name": "certs.exchange",
@@ -193,9 +193,9 @@ class OutpostV1Doc:
                     },
                     "msg": {
                         "action": "CREATE_REMINDER",
-                        "type": "ONETIME",
                         "data": {
                             "identifier": "ORG=Kubefacets,APP=Certs,PRJ=Auth,COLL=Login,CSR=kubefacets Root CA",
+                            "type": "ONETIME",
                             "remind_by_in_mins": 10,
                             "to_msg_queue": {
                                 "exchange_name": "certs.exchange",
@@ -283,9 +283,9 @@ class OutpostV1Doc:
                     },
                     "msg": {
                         "action": "CREATE_REMINDER",
-                        "type": "ONETIME",
                         "data": {
                             "identifier": "ORG=Kubefacets,APP=Certs,PRJ=Auth,COLL=Login,CSR=kubefacets Root CA",
+                            "type": "ONETIME",
                             "remind_by_in_mins": 10,
                             "to_msg_queue": {
                                 "exchange_name": "certs.exchange",
