@@ -2,8 +2,9 @@ from django.db import models
 from django.db.models.signals import post_save
 from django.dispatch import receiver
 import json
+import pika.exceptions
 
-from kfsd.apps.models.base import BaseModel
+from kfsd.apps.models.tables.base import BaseModel
 from kfsd.apps.core.utils.system import System
 from kfsd.apps.core.utils.time import Time
 from kfsd.apps.core.msmq.rabbitmq.base import RabbitMQ
@@ -41,25 +42,35 @@ class Outpost(BaseModel):
 @receiver(post_save, sender=Outpost)
 def signal_send_msg(sender, instance, created, **kwargs):
     if created:
-        send_msg(instance.id)
+        send_msg(instance)
 
 
-def send_msg(instance_id):
-    instance = Outpost.objects.get(id=instance_id)
-    logger.info("Sending msg for outpost id: {}".format(instance.identifier))
-    try:
-        rabbitMQ = RabbitMQ()
-        rabbitMQ.publish_msg_and_close_connection(
-            instance.msg_queue_info["exchange_name"],
-            instance.msg_queue_info["queue_name"],
-            instance.msg_queue_info["routing_key"],
-            json.dumps(instance.msg),
+def log_error(instance):
+    oldDebugInfo = instance.debug_info
+    currentTimeStr = Time.calculate_time(Time.current_time(), {"minutes": 0}, True)
+    oldDebugInfo[currentTimeStr] = "Error occurred in publishing outpost msg"
+    instance.debug_info = oldDebugInfo
+    instance.attempts += 1
+    instance.status = "E"
+    instance.save()
+
+
+def send_msg(instance):
+    logger.info(
+        "Sending msg to MSMQ for outpost id: {}, msmq: {}, msg: {}".format(
+            instance.identifier,
+            json.dumps(instance.msg_queue_info, indent=4),
+            json.dumps(instance.msg, indent=4),
         )
+    )
+    try:
+        configId = System.getEnv("service_id")
+        rabbitMQ = RabbitMQ.getSingleton(configId)
+        rabbitMQ.publish(instance.msg_queue_info, json.dumps(instance.msg))
         instance.delete()
-    except Exception:
-        oldDebugInfo = instance.debug_info
-        currentTimeStr = Time.calculate_time(Time.current_time(), {"minutes": 0}, True)
-        oldDebugInfo[currentTimeStr] = "Error occurred in publishing outpost msg"
-        instance.debug_info = oldDebugInfo
-        instance.attempts += 1
-        instance.save()
+    except pika.exceptions.StreamLostError as e:
+        logger.error("Recd error on publish: {}".format(e.__str__()))
+        log_error(instance)
+    except Exception as e:
+        logger.error("Recd error on publish: {}".format(e.__str__()))
+        log_error(instance)
